==> bl_amazon_api-0.0.4.tgz: package/docs/ToolApi.md <==
# BlAmazonApi.ToolApi

All URIs are relative to *http://104.198.83.158:80*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getDictionaryBrowseNodesAll**](ToolApi.md#getDictionaryBrowseNodesAll) | **GET** /tool/dictionary/browseNodes/{nodeId}/all | Get all dictionary hierarchy within a specified browse node
[**getDictionarySubAttrsWords**](ToolApi.md#getDictionarySubAttrsWords) | **GET** /tool/dictionary/subAttrs/words | Get dictionary words with subAttrId list
[**getDictionaryWords**](ToolApi.md#getDictionaryWords) | **GET** /tool/dictionary/words | Get dictionary words for filtering within specified browse nodes
[**getDictionaryWordsFiltered**](ToolApi.md#getDictionaryWordsFiltered) | **GET** /tool/dictionary/words/{nodeId}/filtered | Get filtered words within a specified browse node with filtering words
[**getToolTitles**](ToolApi.md#getToolTitles) | **GET** /tool/titles/{nodeId} | Get 100 amazon best selling item titles within a specified browse node
[**postDictionaryProductsAttrs**](ToolApi.md#postDictionaryProductsAttrs) | **POST** /tool/dictionary/products/{nodeId}/attrs | Add attribute within a specified browse node&#39;s
[**postDictionaryProductsAttrsSubAttrs**](ToolApi.md#postDictionaryProductsAttrsSubAttrs) | **POST** /tool/dictionary/products/{nodeId}/attrs/{attrId}/subAttrs | Add sub attribute within a specified browse node&#39;s attribute
[**postDictionaryWords**](ToolApi.md#postDictionaryWords) | **POST** /tool/dictionary/words | Add filtering word to dictionary


<a name="getDictionaryBrowseNodesAll"></a>
# **getDictionaryBrowseNodesAll**
> GetDictionaryBrowseNodesAllResponse getDictionaryBrowseNodesAll(nodeId)

Get all dictionary hierarchy within a specified browse node

Return all dictionary hierarchy

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var nodeId = "nodeId_example"; // String | 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getDictionaryBrowseNodesAll(nodeId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nodeId** | **String**|  | 

### Return type

[**GetDictionaryBrowseNodesAllResponse**](GetDictionaryBrowseNodesAllResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDictionarySubAttrsWords"></a>
# **getDictionarySubAttrsWords**
> GetDictionarySubAttrsWordsResponse getDictionarySubAttrsWords(subAttrIds)

Get dictionary words with subAttrId list

Return Dictionary Words

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var subAttrIds = ["subAttrIds_example"]; // [String] | 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getDictionarySubAttrsWords(subAttrIds, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **subAttrIds** | [**[String]**](String.md)|  | 

### Return type

[**GetDictionarySubAttrsWordsResponse**](GetDictionarySubAttrsWordsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDictionaryWords"></a>
# **getDictionaryWords**
> GetDictionaryWordsResponse getDictionaryWords(nodeIds)

Get dictionary words for filtering within specified browse nodes

Return Dictionary Words for filtering ingredients

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var nodeIds = ["nodeIds_example"]; // [String] | 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getDictionaryWords(nodeIds, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nodeIds** | [**[String]**](String.md)|  | 

### Return type

[**GetDictionaryWordsResponse**](GetDictionaryWordsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDictionaryWordsFiltered"></a>
# **getDictionaryWordsFiltered**
> GetDictionaryWordsFilteredResponse getDictionaryWordsFiltered(nodeId, filters)

Get filtered words within a specified browse node with filtering words

Return filtered words cloud

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var nodeId = "nodeId_example"; // String | 

var filters = ["filters_example"]; // [String] | 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getDictionaryWordsFiltered(nodeId, filters, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nodeId** | **String**|  | 
 **filters** | [**[String]**](String.md)|  | 

### Return type

[**GetDictionaryWordsFilteredResponse**](GetDictionaryWordsFilteredResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getToolTitles"></a>
# **getToolTitles**
> GetToolTitlesResponse getToolTitles(nodeId)

Get 100 amazon best selling item titles within a specified browse node

Return Titles

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var nodeId = "nodeId_example"; // String | 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getToolTitles(nodeId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nodeId** | **String**|  | 

### Return type

[**GetToolTitlesResponse**](GetToolTitlesResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="postDictionaryProductsAttrs"></a>
# **postDictionaryProductsAttrs**
> PostDictionaryProductsAttrsResponse postDictionaryProductsAttrs(nodeId, attrId, attrUsName, attrKrName)

Add attribute within a specified browse node&#39;s

Add attribute

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var nodeId = "nodeId_example"; // String | 

var attrId = "attrId_example"; // String | 

var attrUsName = "attrUsName_example"; // String | Upserting if exists

var attrKrName = "attrKrName_example"; // String | Upserting if exists


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.postDictionaryProductsAttrs(nodeId, attrId, attrUsName, attrKrName, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nodeId** | **String**|  | 
 **attrId** | **String**|  | 
 **attrUsName** | **String**| Upserting if exists | 
 **attrKrName** | **String**| Upserting if exists | 

### Return type

[**PostDictionaryProductsAttrsResponse**](PostDictionaryProductsAttrsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="postDictionaryProductsAttrsSubAttrs"></a>
# **postDictionaryProductsAttrsSubAttrs**
> PostDictionaryProductsAttrsSubAttrsResponse postDictionaryProductsAttrsSubAttrs(nodeId, attrId, subAttrId, subAttrUsName, subAttrKrName)

Add sub attribute within a specified browse node&#39;s attribute

Add sub attribute

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var nodeId = "nodeId_example"; // String | 

var attrId = "attrId_example"; // String | 

var subAttrId = "subAttrId_example"; // String | 

var subAttrUsName = "subAttrUsName_example"; // String | Upserting if exists

var subAttrKrName = "subAttrKrName_example"; // String | Upserting if exists


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.postDictionaryProductsAttrsSubAttrs(nodeId, attrId, subAttrId, subAttrUsName, subAttrKrName, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nodeId** | **String**|  | 
 **attrId** | **String**|  | 
 **subAttrId** | **String**|  | 
 **subAttrUsName** | **String**| Upserting if exists | 
 **subAttrKrName** | **String**| Upserting if exists | 

### Return type

[**PostDictionaryProductsAttrsSubAttrsResponse**](PostDictionaryProductsAttrsSubAttrsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="postDictionaryWords"></a>
# **postDictionaryWords**
> PostDictionaryWordsResponse postDictionaryWords(subAttrId, word)

Add filtering word to dictionary

Add to dictionary

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var subAttrId = "subAttrId_example"; // String | 

var word = "word_example"; // String | 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.postDictionaryWords(subAttrId, word, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **subAttrId** | **String**|  | 
 **word** | **String**|  | 

### Return type

[**PostDictionaryWordsResponse**](PostDictionaryWordsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

==> bl_amazon_api-0.0.5.tgz: package/docs/ToolApi.md <==
# BlAmazonApi.ToolApi

All URIs are relative to *http://104.198.83.158:80*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getDictionaryBrowseNodesAll**](ToolApi.md#getDictionaryBrowseNodesAll) | **GET** /tool/dictionary/browseNodes/{nodeId}/all | Get all dictionary hierarchy within a specified browse node
[**getDictionaryProductsAttrs**](ToolApi.md#getDictionaryProductsAttrs) | **GET** /tool/dictionary/products/{nodeId}/attrs/{attrId} | Get an attribute within a specified browse node&#39;s
[**getDictionaryProductsAttrsSubAttrs**](ToolApi.md#getDictionaryProductsAttrsSubAttrs) | **GET** /tool/dictionary/products/{nodeId}/attrs/{attrId}/subAttrs/{subAttrId} | Get a sub attribute within a specified browse node&#39;s attribute
[**getDictionaryProductsAttrsSubAttrsWords**](ToolApi.md#getDictionaryProductsAttrsSubAttrsWords) | **GET** /tool/dictionary/products/{nodeId}/attrs/{attrId}/subAttrs/{subAttrId}/words | Check the dic_word contains within a specified browse node&#39;s attribute&#39;s sub attribute
[**getDictionarySubAttrsWords**](ToolApi.md#getDictionarySubAttrsWords) | **GET** /tool/dictionary/subAttrs/words | Get dictionary words with subAttrId list
[**getDictionaryWords**](ToolApi.md#getDictionaryWords) | **GET** /tool/dictionary/words | [DEPRECATED] Get dictionary words for filtering within specified browse nodes
[**getDictionaryWordsFiltered**](ToolApi.md#getDictionaryWordsFiltered) | **GET** /tool/dictionary/words/{nodeId}/filtered | Get filtered words within a specified browse node with filtering words
[**getToolTitles**](ToolApi.md#getToolTitles) | **GET** /tool/titles/{nodeId} | Get 100 amazon best selling item titles within a specified browse node
[**postDictionaryProductsAttrs**](ToolApi.md#postDictionaryProductsAttrs) | **POST** /tool/dictionary/products/{nodeId}/attrs/{attrId} | Add attribute within a specified browse node&#39;s
[**postDictionaryProductsAttrsSubAttrs**](ToolApi.md#postDictionaryProductsAttrsSubAttrs) | **POST** /tool/dictionary/products/{nodeId}/attrs/{attrId}/subAttrs/{subAttrId} | Add sub attribute within a specified browse node&#39;s attribute
[**postDictionaryProductsAttrsSubAttrsWords**](ToolApi.md#postDictionaryProductsAttrsSubAttrsWords) | **POST** /tool/dictionary/products/{nodeId}/attrs/{attrId}/subAttrs/{subAttrId}/words | Add a dic_word within a specified browse node&#39;s attribute&#39;s sub attribute
[**postDictionaryWords**](ToolApi.md#postDictionaryWords) | **POST** /tool/dictionary/words | [DEPRECATED] Add filtering word to dictionary


<a name="getDictionaryBrowseNodesAll"></a>
# **getDictionaryBrowseNodesAll**
> GetDictionaryBrowseNodesAllResponse getDictionaryBrowseNodesAll(nodeId)

Get all dictionary hierarchy within a specified browse node

Return all dictionary hierarchy

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var nodeId = "nodeId_example"; // String | 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getDictionaryBrowseNodesAll(nodeId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nodeId** | **String**|  | 

### Return type

[**GetDictionaryBrowseNodesAllResponse**](GetDictionaryBrowseNodesAllResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDictionaryProductsAttrs"></a>
# **getDictionaryProductsAttrs**
> GetDictionaryProductsAttrsResponse getDictionaryProductsAttrs(nodeId, attrId)

Get an attribute within a specified browse node&#39;s

Return an attribute

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var nodeId = "nodeId_example"; // String | 

var attrId = "attrId_example"; // String | 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getDictionaryProductsAttrs(nodeId, attrId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nodeId** | **String**|  | 
 **attrId** | **String**|  | 

### Return type

[**GetDictionaryProductsAttrsResponse**](GetDictionaryProductsAttrsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDictionaryProductsAttrsSubAttrs"></a>
# **getDictionaryProductsAttrsSubAttrs**
> GetDictionaryProductsAttrsSubAttrsResponse getDictionaryProductsAttrsSubAttrs(nodeId, attrId, subAttrId)

Get a sub attribute within a specified browse node&#39;s attribute

Get a sub attribute

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var nodeId = "nodeId_example"; // String | 

var attrId = "attrId_example"; // String | 

var subAttrId = "subAttrId_example"; // String | 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getDictionaryProductsAttrsSubAttrs(nodeId, attrId, subAttrId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nodeId** | **String**|  | 
 **attrId** | **String**|  | 
 **subAttrId** | **String**|  | 

### Return type

[**GetDictionaryProductsAttrsSubAttrsResponse**](GetDictionaryProductsAttrsSubAttrsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDictionaryProductsAttrsSubAttrsWords"></a>
# **getDictionaryProductsAttrsSubAttrsWords**
> GetDictionaryProductsAttrsSubAttrsWordsResponse getDictionaryProductsAttrsSubAttrsWords(nodeId, attrId, subAttrId, word)

Check the dic_word contains within a specified browse node&#39;s attribute&#39;s sub attribute

Checket a dic_word contains

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var nodeId = "nodeId_example"; // String | 

var attrId = "attrId_example"; // String | 

var subAttrId = "subAttrId_example"; // String | 

var word = "word_example"; // String | 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getDictionaryProductsAttrsSubAttrsWords(nodeId, attrId, subAttrId, word, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nodeId** | **String**|  | 
 **attrId** | **String**|  | 
 **subAttrId** | **String**|  | 
 **word** | **String**|  | 

### Return type

[**GetDictionaryProductsAttrsSubAttrsWordsResponse**](GetDictionaryProductsAttrsSubAttrsWordsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDictionarySubAttrsWords"></a>
# **getDictionarySubAttrsWords**
> GetDictionarySubAttrsWordsResponse getDictionarySubAttrsWords(subAttrIds)

Get dictionary words with subAttrId list

Return Dictionary Words

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var subAttrIds = ["subAttrIds_example"]; // [String] | 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getDictionarySubAttrsWords(subAttrIds, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **subAttrIds** | [**[String]**](String.md)|  | 

### Return type

[**GetDictionarySubAttrsWordsResponse**](GetDictionarySubAttrsWordsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDictionaryWords"></a>
# **getDictionaryWords**
> GetDictionaryWordsResponse getDictionaryWords(nodeIds)

[DEPRECATED] Get dictionary words for filtering within specified browse nodes

[DEPRECATED] Return Dictionary Words for filtering ingredients

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var nodeIds = ["nodeIds_example"]; // [String] | 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getDictionaryWords(nodeIds, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nodeIds** | [**[String]**](String.md)|  | 

### Return type

[**GetDictionaryWordsResponse**](GetDictionaryWordsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDictionaryWordsFiltered"></a>
# **getDictionaryWordsFiltered**
> GetDictionaryWordsFilteredResponse getDictionaryWordsFiltered(nodeId, filters)

Get filtered words within a specified browse node with filtering words

Return filtered words cloud

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var nodeId = "nodeId_example"; // String | 

var filters = ["filters_example"]; // [String] | 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getDictionaryWordsFiltered(nodeId, filters, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nodeId** | **String**|  | 
 **filters** | [**[String]**](String.md)|  | 

### Return type

[**GetDictionaryWordsFilteredResponse**](GetDictionaryWordsFilteredResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getToolTitles"></a>
# **getToolTitles**
> GetToolTitlesResponse getToolTitles(nodeId)

Get 100 amazon best selling item titles within a specified browse node

Return Titles

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var nodeId = "nodeId_example"; // String | 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.getToolTitles(nodeId, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nodeId** | **String**|  | 

### Return type

[**GetToolTitlesResponse**](GetToolTitlesResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="postDictionaryProductsAttrs"></a>
# **postDictionaryProductsAttrs**
> PostDictionaryProductsAttrsResponse postDictionaryProductsAttrs(nodeId, attrId, attrUsName, attrKrName)

Add attribute within a specified browse node&#39;s

Add attribute

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var nodeId = "nodeId_example"; // String | 

var attrId = "attrId_example"; // String | 

var attrUsName = "attrUsName_example"; // String | Upserting if exists

var attrKrName = "attrKrName_example"; // String | Upserting if exists


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.postDictionaryProductsAttrs(nodeId, attrId, attrUsName, attrKrName, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nodeId** | **String**|  | 
 **attrId** | **String**|  | 
 **attrUsName** | **String**| Upserting if exists | 
 **attrKrName** | **String**| Upserting if exists | 

### Return type

[**PostDictionaryProductsAttrsResponse**](PostDictionaryProductsAttrsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="postDictionaryProductsAttrsSubAttrs"></a>
# **postDictionaryProductsAttrsSubAttrs**
> PostDictionaryProductsAttrsSubAttrsResponse postDictionaryProductsAttrsSubAttrs(nodeId, attrId, subAttrId, subAttrUsName, subAttrKrName)

Add sub attribute within a specified browse node&#39;s attribute

Add sub attribute

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var nodeId = "nodeId_example"; // String | 

var attrId = "attrId_example"; // String | 

var subAttrId = "subAttrId_example"; // String | 

var subAttrUsName = "subAttrUsName_example"; // String | Upserting if exists

var subAttrKrName = "subAttrKrName_example"; // String | Upserting if exists


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.postDictionaryProductsAttrsSubAttrs(nodeId, attrId, subAttrId, subAttrUsName, subAttrKrName, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nodeId** | **String**|  | 
 **attrId** | **String**|  | 
 **subAttrId** | **String**|  | 
 **subAttrUsName** | **String**| Upserting if exists | 
 **subAttrKrName** | **String**| Upserting if exists | 

### Return type

[**PostDictionaryProductsAttrsSubAttrsResponse**](PostDictionaryProductsAttrsSubAttrsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="postDictionaryProductsAttrsSubAttrsWords"></a>
# **postDictionaryProductsAttrsSubAttrsWords**
> PostDictionaryProductsAttrsSubAttrsWordsResponse postDictionaryProductsAttrsSubAttrsWords(nodeId, attrId, subAttrId, word)

Add a dic_word within a specified browse node&#39;s attribute&#39;s sub attribute

Add a dic_word

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var nodeId = "nodeId_example"; // String | 

var attrId = "attrId_example"; // String | 

var subAttrId = "subAttrId_example"; // String | 

var word = "word_example"; // String | 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.postDictionaryProductsAttrsSubAttrsWords(nodeId, attrId, subAttrId, word, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nodeId** | **String**|  | 
 **attrId** | **String**|  | 
 **subAttrId** | **String**|  | 
 **word** | **String**|  | 

### Return type

[**PostDictionaryProductsAttrsSubAttrsWordsResponse**](PostDictionaryProductsAttrsSubAttrsWordsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="postDictionaryWords"></a>
# **postDictionaryWords**
> PostDictionaryWordsResponse postDictionaryWords(subAttrId, word)

[DEPRECATED] Add filtering word to dictionary

[DEPRECATED] Add to dictionary

### Example
```javascript
var BlAmazonApi = require('bl_amazon_api');

var apiInstance = new BlAmazonApi.ToolApi();

var subAttrId = "subAttrId_example"; // String | 

var word = "word_example"; // String | 


var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
apiInstance.postDictionaryWords(subAttrId, word, callback);
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **subAttrId** | **String**|  | 
 **word** | **String**|  | 

### Return type

[**PostDictionaryWordsResponse**](PostDictionaryWordsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json
